==> spip_4.0.4.orig.tar.xz: plugins-dist/bigup/lang/bigup_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-bigup?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bigup_titre' => 'Big Upload',
	'bouton_annuler' => 'Cancel',
	'bouton_enlever' => 'Remove',

	// C
	'cfg_charger_public' => 'Script in the public website',
	'cfg_charger_public_case' => 'Load scripts on the public website',
	'cfg_max_file_size' => 'Maximum size of files',
	'cfg_max_file_size_explication' => 'Maximum size of files (in Mb).',
	'cfg_titre_parametrages' => 'Big Upload settings',
	'choisir' => 'Choose',

	// D
	'deposer_la_vignette_ici' => 'Drop the thumbnail here',
	'deposer_le_logo_ici' => 'Drop the LOGO here',
	'deposer_vos_fichiers_ici' => 'Drop your files here',
	'deposer_votre_fichier_ici' => 'Drop your file here',

	// E
	'erreur_de_transfert' => 'Upload error',
	'erreur_probleme_survenu' => 'Some trouble occured…',
	'erreur_taille_max' => 'Maximum file size is @taille@',
	'erreur_type_fichier' => 'File type unallowed!',

	// F
	'fichier_efface' => 'File deleted',

	// O
	'ou' => 'or',

	// S
	'selectionner' => 'Select',
	'succes_fichier_envoye' => 'File has been sent',
	'succes_logo_envoye' => 'Logo has been sent',
	'succes_vignette_envoyee' => 'Thumbnail has been sent',

	// T
	'televerser' => 'Upload',
	'titre_page_configurer_bigup' => 'Big Upload Configuration',

	// Z
	'zbug_necessite_plugin' => 'The <code>@balise@</code> tag needs the plugin <code>@plugin@</code>'
);

==> spip_4.1.11+dfsg.orig.tar.xz: plugins-dist/bigup/lang/bigup_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-bigup?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bigup_titre' => 'Big Upload',
	'bouton_annuler' => 'Cancel',
	'bouton_enlever' => 'Remove',

	// C
	'cfg_charger_public' => 'Script in the public website',
	'cfg_charger_public_case' => 'Load scripts on the public website',
	'cfg_explication_parametrages' => 'These options target only the file fields managed by drag and drop.',
	'cfg_max_file_size' => 'Maximum size of files',
	'cfg_max_file_size_explication' => 'Maximum size of files (in Mb).',
	'cfg_titre_parametrages' => 'File Upload',
	'choisir' => 'Choose',

	// D
	'deposer_la_vignette_ici' => 'Drop the thumbnail here',
	'deposer_le_logo_ici' => 'Drop the LOGO here',
	'deposer_vos_fichiers_ici' => 'Drop your files here',
	'deposer_votre_fichier_ici' => 'Drop your file here',

	// E
	'erreur_de_transfert' => 'Upload error',
	'erreur_probleme_survenu' => 'Some trouble occured…',
	'erreur_taille_max' => 'Maximum file size is @taille@',
	'erreur_type_fichier' => 'File type unallowed!',

	// F
	'fichier_efface' => 'File deleted',

	// O
	'ou' => 'or',

	// S
	'selectionner' => 'Select',
	'succes_fichier_envoye' => 'File has been sent',
	'succes_logo_envoye' => 'Logo has been sent',
	'succes_vignette_envoyee' => 'Thumbnail has been sent',

	// T
	'televerser' => 'Upload',
	'titre_page_configurer_bigup' => 'Big Upload Configuration',

	// Z
	'zbug_necessite_plugin' => 'The <code>@balise@</code> tag needs the plugin <code>@plugin@</code>'
);
